AppUtils class

Constructors

AppUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

readLine(String type) Future<String>
stringJoin(String parent, [String? p1, String? p2, String? p3, String? p4]) String
upperCamelCase(String name) String
PascalCase from snake_case or kebab-case (e.g. new_featureNewFeature).